package com.dkl.large.mapper;

import java.util.List;
import com.dkl.large.domain.DklVideoData;
import com.dkl.large.domain.vo.DklMonitoringCameraDataVo;

/**
 * 大客流视频数据获取Mapper接口
 *
 * @author Dkl
 * @date 2025-06-06
 */
public interface DklVideoDataMapper
{
    /**
     * 查询大客流视频数据获取
     *
     * @param id 大客流视频数据获取主键
     * @return 大客流视频数据获取
     */
    public DklVideoData selectDklVideoDataById(int id);

    /**
     * 查询大客流视频数据获取列表
     *
     * @param dklVideoData 大客流视频数据获取
     * @return 大客流视频数据获取集合
     */
    public List<DklVideoData> selectDklVideoDataList(DklVideoData dklVideoData);

    /**
     * 新增大客流视频数据获取
     *
     * @param dklVideoData 大客流视频数据获取
     * @return 结果
     */
    public int insertDklVideoData(DklVideoData dklVideoData);

    /**
     * 修改大客流视频数据获取
     *
     * @param dklVideoData 大客流视频数据获取
     * @return 结果
     */
    public int updateDklVideoData(DklVideoData dklVideoData);

    /**
     * 删除大客流视频数据获取
     *
     * @param id 大客流视频数据获取主键
     * @return 结果
     */
    public int deleteDklVideoDataById(int id);

    /**
     * 批量删除大客流视频数据获取
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteDklVideoDataByIds(int[] ids);

    /**
     * @Author :rq
     * @Description :监控点摄像头数据获取人员数量
     * @Date :2025/06/12 11:14
     * @Param :[]
     * @return :java.lang.String
     **/
    public String getDklVideoDataCount();

    /**
     * @Author :rq
     * @Description :监控点摄像头数据获取人员数量
     * @Date :2025/06/12 11:14
     * @Param :[]
     * @return :java.lang.String
     **/
    public String getDklVideoDataPeopleCount();
    /**
     * @Author :rq
     * @Description :获取数据人数 时间段内
     * @Date :2025/06/12 13:35
     * @Param :[dklMonitoringCameraDataVo]
     * @return :java.util.List<com.dkl.large.domain.vo.DklMonitoringCameraDataVo>
     **/
    public List<DklMonitoringCameraDataVo>  peopleDataStatisticsByActivity(DklMonitoringCameraDataVo dklMonitoringCameraDataVo);

    /**
     * @Author :rq
     * @Description :获取数据条数 时间段内
     * @Date :2025/06/12 13:35
     * @Param :[dklMonitoringCameraDataVo]
     * @return :java.util.List<com.dkl.large.domain.vo.DklMonitoringCameraDataVo>
     **/
    public List<DklMonitoringCameraDataVo>  itemsDataStatisticsByActivity(DklMonitoringCameraDataVo dklMonitoringCameraDataVo);
}
